@@ -35,6 +35,7 @@ package org.slf4j.impl;
 
 import org.slf4j.ILoggerFactory;
 import org.slf4j.LoggerFactory;
+import org.slf4j.helpers.NOPLoggerFactory;
 import org.slf4j.spi.LoggerFactoryBinder;
 
 /**
@@ -66,7 +67,7 @@ public class StaticLoggerBinder  implements LoggerFactoryBinder {
    * The value of this field is usually modified with each release. 
    */
   // to avoid constant folding by the compiler, this field must *not* be final
-  public static String REQUESTED_API_VERSION = "1.5.11";  // !final
+  public static String REQUESTED_API_VERSION = "1.6";  // !final
   
   private static final String loggerFactoryClassStr = NOPLoggerFactory.class.getName();
 
